<?php

/**
 * Plugin Name: Fake Customer Blocker for WordPress
 * Description: Fake Customer Blocker plugin blocks your unwanted spam customers who come to your site and download free items with fake email addresses and test user details.
 * Plugin URI: https://www.techeshta.com/product/fake-customer-blocker-for-wordpress/
 * Author: 20script
 * Version: 1.0.6
 * Author URI: https://www.20script.ir
 *
 * Text Domain: fake-customer-blocker
 */
if (!defined('ABSPATH')) {
    exit;
}
define('FCB_PLUGIN_DIR', plugin_dir_path(__FILE__));
define('FCB_PLUGIN_URL', plugins_url('/', __FILE__));
define('FCB_DOMAIN', 'fake-customer-blocker');

/**
 * 
 * Check class exists or not
 *  
 * @access public
 * @since  1.0.0
 * 
 * */
if (!class_Exists('FakeCustomerBlocker')) {

    class FakeCustomerBlocker {

        var $locale;

        function __construct($locale, $includes, $path) {
            $this->locale = $locale;
            $this->hooks();

            // Make plugin translation ready
            add_action('plugins_loaded', array($this, 'fcb_edd_load_plugin'));

            // Include file
            foreach ($includes as $single_path) {
                include( $path . $single_path );
            }
        }

        function hooks() {
            add_filter('wc_get_template', array($this, 'cma_get_template'), 1, 5);
            add_filter('plugin_action_links_' . plugin_basename(__FILE__), array($this, 'fake_customer_blocker_y'));
            add_action('admin_enqueue_scripts', array($this, 'fcb_user_scripts'));
            add_action('admin_init', array($this, 'fcb_options_table_update'));
        }

        // Update table default value
        function fcb_options_table_update() {

            $option_name = 'fcb_wp_options';
            $new_value = array('fcbwp-check-enable-for' => array('WC'));

            if (!get_option($option_name) && class_exists('WooCommerce')) {

                // The option already exists, so update it.
                update_option($option_name, $new_value);
            }
        }

        /**
         * Implement string translation
         * 
         * @access public
         * @since  1.0.0 
         * 
         * */        
        function fcb_edd_load_plugin() {
            load_plugin_textdomain('FCB_DOMAIN', false, dirname(plugin_basename(__FILE__)) . '/languages');
        }

        /**
         * override the order-download.php file to block the file downloads if email invalid
         * 
         * @access public
         * @since  1.0.0 
         * 
         * */
        function cma_get_template($located, $template_name, $args, $template_path, $default_path) {

            if ('order/order-downloads.php' == $template_name) {
                $located = plugin_dir_path(__FILE__) . 'templates/woocommerce/order/order-downloads.php';
            }

            return $located;
        }

        /**
         * 
         * Show action links on the plugin screen
         * 
         * @access public
         * @since  1.0.0 
         * 
         * */
        function fake_customer_blocker_y($links) {
            $action_links = array(
                'settings' => '<a href="' . admin_url('admin.php?page=fake_customer_blocker_for_wordpress') . '" aria-label="' . esc_attr__('View Share reviews settings', FCB_DOMAIN) . '">' . esc_html__('Settings', FCB_DOMAIN) . '</a>',
                'docs' => '<a href="#" target="_blank">' . esc_html__('Docs', FCB_DOMAIN) . '</a>',
            );
            return array_merge($action_links, $links);
        }

        /**
         * @return Enqueue style and script
         * 
         * @access public
         * @since  1.0.0
         */
        function fcb_user_scripts() {
            wp_enqueue_style('fcb-select2-function-css', FCB_PLUGIN_URL . 'assets/css/fcb-select2.css');
            wp_enqueue_script('fcb-select2-function-js', FCB_PLUGIN_URL . 'assets/js/fcb-select2.js', array('jquery'), false, true);
        }

    }

}

/**
 *
 * Initialize the class
 * @since  1.0.0
 *
 * */
new FakeCustomerBlocker('fcb', array(
    'modules/scripts.php',
    'modules/settings.php',
    'modules/hooks.php'
        ), dirname(__FILE__) . '/');
